@@ -92,6 +92,9 @@ FAILEDOPERATION_DOMAINALREADYBINDOTHERSERVICE = 'FailedOperation.DomainAlreadyBi
 # The domain name has already been bound to this service.
 FAILEDOPERATION_DOMAINALREADYBINDSERVICE = 'FailedOperation.DomainAlreadyBindService'
 
+# Unable to connect: the current domain name is not compliant. 
+FAILEDOPERATION_DOMAININBLACKLIST = 'FailedOperation.DomainInBlackList'
+
 # The domain name does not have an ICP filing through Tencent Cloud. Please get the ICP filing before binding the domain name.
 FAILEDOPERATION_DOMAINNEEDBEIAN = 'FailedOperation.DomainNeedBeian'
 
@@ -131,6 +134,9 @@ FAILEDOPERATION_SCFERROR = 'FailedOperation.ScfError'
 # Service error.
 FAILEDOPERATION_SERVICEERROR = 'FailedOperation.ServiceError'
 
+# The service is in use. Please try again later.
+FAILEDOPERATION_SERVICEINOPERATION = 'FailedOperation.ServiceInOperation'
+
 # The service does not exist.
 FAILEDOPERATION_SERVICENOTEXIST = 'FailedOperation.ServiceNotExist'
 
@@ -152,6 +158,9 @@ INTERNALERROR = 'InternalError'
 # API Gateway internal request error. Please try again later. If the problem persists, please contact the smart customer service or submit a ticket.
 INTERNALERROR_APIGWEXCEPTION = 'InternalError.ApigwException'
 
+# CAuth internal request error. Please try again later. If the problem persists, please submit a ticket.
+INTERNALERROR_CAUTHEXCEPTION = 'InternalError.CauthException'
+
 # OSS internal request error. Please try again. If the problem persists, please contact the smart customer service or submit a ticket.
 INTERNALERROR_OSSEXCEPTION = 'InternalError.OssException'
 
@@ -173,13 +182,19 @@ INVALIDPARAMETER_FORMATERROR = 'InvalidParameter.FormatError'
 # The parameter value is incorrect.
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# Duplicate plugin parameter values. Please modify and try again.
+INVALIDPARAMETERVALUE_DUPLICATEPLUGINCONFIG = 'InvalidParameterValue.DuplicatePluginConfig'
+
+# 
+INVALIDPARAMETERVALUE_ILLEGALPROXYIP = 'InvalidParameterValue.IllegalProxyIp'
+
 # Incorrect key.
 INVALIDPARAMETERVALUE_INVALIDACCESSKEYIDS = 'InvalidParameterValue.InvalidAccessKeyIds'
 
 # The API business type passed in must be `OAUTH`.
 INVALIDPARAMETERVALUE_INVALIDAPIBUSINESSTYPE = 'InvalidParameterValue.InvalidApiBusinessType'
 
-# 
+# Incorrect API ID
 INVALIDPARAMETERVALUE_INVALIDAPIIDS = 'InvalidParameterValue.InvalidApiIds'
 
 # Invalid API configuration.
@@ -194,9 +209,18 @@ INVALIDPARAMETERVALUE_INVALIDBACKENDPATH = 'InvalidParameterValue.InvalidBackend
 # Invalid CLB configuration.
 INVALIDPARAMETERVALUE_INVALIDCLB = 'InvalidParameterValue.InvalidClb'
 
+# Policy error.
+INVALIDPARAMETERVALUE_INVALIDCONDITION = 'InvalidParameterValue.InvalidCondition'
+
 # The constant parameter is invalid.
 INVALIDPARAMETERVALUE_INVALIDCONSTANTPARAMETERS = 'InvalidParameterValue.InvalidConstantParameters'
 
+# The value of the `Env` parameter is incorrect. Its valid values are (release, prepub, test).
+INVALIDPARAMETERVALUE_INVALIDENV = 'InvalidParameterValue.InvalidEnv'
+
+# Invalid service environment status
+INVALIDPARAMETERVALUE_INVALIDENVSTATUS = 'InvalidParameterValue.InvalidEnvStatus'
+
 # The parameter value is incorrect.
 INVALIDPARAMETERVALUE_INVALIDFILTERNOTSUPPORTEDNAME = 'InvalidParameterValue.InvalidFilterNotSupportedName'
 
@@ -209,6 +233,9 @@ INVALIDPARAMETERVALUE_INVALIDIPADDRESS = 'InvalidParameterValue.InvalidIPAddress
 # The method is incorrect. For backend services in the WEBSOCKET type, the frontend method should be configured as GET.
 INVALIDPARAMETERVALUE_INVALIDMETHOD = 'InvalidParameterValue.InvalidMethod'
 
+# Plugin parameter value error. Please modify and try again.
+INVALIDPARAMETERVALUE_INVALIDPLUGINCONFIG = 'InvalidParameterValue.InvalidPluginConfig'
+
 # The backend service port is incorrect.
 INVALIDPARAMETERVALUE_INVALIDPORT = 'InvalidParameterValue.InvalidPort'
 
@@ -242,7 +269,7 @@ INVALIDPARAMETERVALUE_INVALIDSERVICEPARAMETERS = 'InvalidParameterValue.InvalidS
 # The backend service type is incorrect. For backend services in WEBSOCKET type, the frontend protocol should be configured as WEBSOCKET.
 INVALIDPARAMETERVALUE_INVALIDSERVICETYPE = 'InvalidParameterValue.InvalidServiceType'
 
-# 
+# Incorrect tag parameters
 INVALIDPARAMETERVALUE_INVALIDTAGVALUES = 'InvalidParameterValue.InvalidTagValues'
 
 # Incorrect configuration of the TSF-type API.
@@ -281,6 +308,9 @@ LIMITEXCEEDED = 'LimitExceeded'
 # The number of API documents exceeds the limit.
 LIMITEXCEEDED_APIDOCLIMITEXCEEDED = 'LimitExceeded.APIDocLimitExceeded'
 
+# Number of applications bound with the service reaches the upper limit.
+LIMITEXCEEDED_APIAPPCOUNTLIMITEXCEEDED = 'LimitExceeded.ApiAppCountLimitExceeded'
+
 # The number of APIs exceeds the limit.
 LIMITEXCEEDED_APICOUNTLIMITEXCEEDED = 'LimitExceeded.ApiCountLimitExceeded'
 
@@ -299,6 +329,9 @@ LIMITEXCEEDED_IPSTRATEGYLIMITEXCEEDED = 'LimitExceeded.IpStrategyLimitExceeded'
 # The request frequency has reached the limit. Please try again later.
 LIMITEXCEEDED_REQUESTLIMITEXCEEDED = 'LimitExceeded.RequestLimitExceeded'
 
+# Too many services are bound to the plugin. Unbind some services or increase the quota, and try again.
+LIMITEXCEEDED_SERVICECOUNTFORPLUGINLIMITEXCEEDED = 'LimitExceeded.ServiceCountForPluginLimitExceeded'
+
 # The number of services exceeds the limit. Please delete some services or increase the limit and try again.
 LIMITEXCEEDED_SERVICECOUNTLIMITEXCEEDED = 'LimitExceeded.ServiceCountLimitExceeded'
 
@@ -329,6 +362,9 @@ RESOURCENOTFOUND_INVALIDACCESSKEYID = 'ResourceNotFound.InvalidAccessKeyId'
 # Incorrect `ApiId`.
 RESOURCENOTFOUND_INVALIDAPI = 'ResourceNotFound.InvalidApi'
 
+# The application ID is incorrect.
+RESOURCENOTFOUND_INVALIDAPIAPP = 'ResourceNotFound.InvalidApiApp'
+
 # The API document does not exist.
 RESOURCENOTFOUND_INVALIDAPIDOC = 'ResourceNotFound.InvalidApiDoc'
 
@@ -338,6 +374,9 @@ RESOURCENOTFOUND_INVALIDIPSTRATEGY = 'ResourceNotFound.InvalidIPStrategy'
 # Error with the OAuth service API.
 RESOURCENOTFOUND_INVALIDOAUTHAPI = 'ResourceNotFound.InvalidOauthApi'
 
+# The plugin does not exist.
+RESOURCENOTFOUND_INVALIDPLUGIN = 'ResourceNotFound.InvalidPlugin'
+
 # The corresponding service is invisible.
 RESOURCENOTFOUND_INVALIDSERVICE = 'ResourceNotFound.InvalidService'
 
@@ -368,6 +407,9 @@ UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 # The key has already been bound to a usage plan.
 UNSUPPORTEDOPERATION_ALREADYBINDUSAGEPLAN = 'UnsupportedOperation.AlreadyBindUsagePlan'
 
+# The current plugin cannot be bound.
+UNSUPPORTEDOPERATION_ATTACHPLUGIN = 'UnsupportedOperation.AttachPlugin'
+
 # Cannot force HTTPS when the protocol is HTTP.
 UNSUPPORTEDOPERATION_FORCEHTTPS = 'UnsupportedOperation.ForceHttps'
 
@@ -383,6 +425,12 @@ UNSUPPORTEDOPERATION_INVALIDSERVICETRADE = 'UnsupportedOperation.InvalidServiceT
 # The current key status does not support this operation.
 UNSUPPORTEDOPERATION_INVALIDSTATUS = 'UnsupportedOperation.InvalidStatus'
 
+# The EIAM authentication API cannot be modified.
+UNSUPPORTEDOPERATION_MODIFYEIAMAUTHAPI = 'UnsupportedOperation.ModifyEIAMAuthApi'
+
+# The network type cannot be modified
+UNSUPPORTEDOPERATION_MODIFYNETTYPE = 'UnsupportedOperation.ModifyNetType'
+
 # The frontend protocol type cannot be changed.
 UNSUPPORTEDOPERATION_MODIFYPROTOCOL = 'UnsupportedOperation.ModifyProtocol'
 
@@ -407,9 +455,15 @@ UNSUPPORTEDOPERATION_UNSUPPORTEDBINDAPIKEY = 'UnsupportedOperation.UnsupportedBi
 # The environment cannot be bound.
 UNSUPPORTEDOPERATION_UNSUPPORTEDBINDENVIRONMENT = 'UnsupportedOperation.UnsupportedBindEnvironment'
 
+# The current API has already been bound to a business API. Please unbind it and try again.
+UNSUPPORTEDOPERATION_UNSUPPORTEDDELETEAPI = 'UnsupportedOperation.UnsupportedDeleteApi'
+
 # This service is being used and cannot be deleted.
 UNSUPPORTEDOPERATION_UNSUPPORTEDDELETESERVICE = 'UnsupportedOperation.UnsupportedDeleteService'
 
+# Unsupported network type
+UNSUPPORTEDOPERATION_UNSUPPORTEDNETTYPE = 'UnsupportedOperation.UnsupportedNetType'
+
 # The environment cannot be unbound, as there are APIs that are not bound to a usage plan.
 UNSUPPORTEDOPERATION_UNSUPPORTEDUNBINDENVIRONMENT = 'UnsupportedOperation.UnsupportedUnBindEnvironment'
 
