@@ -306,6 +306,34 @@ class TcaplusdbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteTableDataFlow(self, request):
+        """This API is used to disable data subscription for tables.
+
+        :param request: Request instance for DeleteTableDataFlow.
+        :type request: :class:`tencentcloud.tcaplusdb.v20190823.models.DeleteTableDataFlowRequest`
+        :rtype: :class:`tencentcloud.tcaplusdb.v20190823.models.DeleteTableDataFlowResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteTableDataFlow", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteTableDataFlowResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteTableGroup(self, request):
         """This API is used to delete a table group.
 
@@ -1286,6 +1314,34 @@ class TcaplusdbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def SetTableDataFlow(self, request):
+        """This API is used to enable data subscription for tables or modify the feature's configurations.
+
+        :param request: Request instance for SetTableDataFlow.
+        :type request: :class:`tencentcloud.tcaplusdb.v20190823.models.SetTableDataFlowRequest`
+        :rtype: :class:`tencentcloud.tcaplusdb.v20190823.models.SetTableDataFlowResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("SetTableDataFlow", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SetTableDataFlowResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SetTableIndex(self, request):
         """This API is used to create a global index for a table.
 
